/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.lifecycle;

import org.xj4.spi.XJ4ExtensionProviderBase;
import org.xj4.spi.MethodWrapperSource;
import org.xj4.spi.ClassWrapperSource;
import org.xj4.spi.TestClassValidator;

/**
 * Extension provider that provides the lifecycle functionality.  For each field in the test class annotated with
 * {@link Manage @Manage}, this extension provider will use {@link LifecycleProvider} implementations to provide class
 * or method wrappers. 
 *
 * @author Jared Bunting
 */
public class LifecycleExtensionProvider extends XJ4ExtensionProviderBase {

  private LifecycleManager lifecycleManager = new LifecycleManager();

  @Override
  protected MethodWrapperSource getMethodWrapperSource() {
    return lifecycleManager;
  }

  @Override
  protected ClassWrapperSource getClassWrapperSource() {
    return lifecycleManager;
  }

  @Override
  protected TestClassValidator getTestClassValidator() {
    return lifecycleManager;
  }
}
