/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.lifecycle;

import java.lang.reflect.Field;
import java.util.List;

/**
 * The service-level provider of a lifecycle.  Responsible for providing lifecycle instances that apply to a specific 
 * field.
 * 
 * @author Jared Bunting
 */
public interface LifecycleProvider {

  /**
   * Determines if this provider can provide a lifecycle for the given field.
   *
   * @param field the field to potentially manage
   * @return true if a lifecycle can be provided, false otherwise
   */
  public boolean canHandle(Field field);

  /**
   * Provides a list of lifecycles for the given field.
   * @param field the field to manage
   * @return the list of lifecycles
   */
  public List<? extends Lifecycle> handle(Field field);
}
